@@ -2,11 +2,15 @@
  *  R : A Computer Language for Statistical Data Analysis
  *  Copyright (C) 1998-2016  The R Core Team
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This header file is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation; either version 2.1 of the License, or
  *  (at your option) any later version.
  *
+ *  This file is part of R. R is distributed under the terms of the
+ *  GNU General Public License, either Version 2, June 1991 or Version 3,
+ *  June 2007. See doc/COPYRIGHTS for details of the copyright status of R.
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -25,13 +29,12 @@
 #ifndef R_EXT_MEMORY_H_
 #define R_EXT_MEMORY_H_
 
-#ifndef NO_C_HEADERS
-# if defined(__cplusplus) && !defined(DO_NOT_USE_CXX_HEADERS)
-#  include <cstddef>
-using std::size_t;
-# else
-#  include <stddef.h> /* for size_t */
-# endif
+#if defined(__cplusplus) && !defined(DO_NOT_USE_CXX_HEADERS)
+# include <cstddef>
+# define R_SIZE_T std::size_t
+#else
+# include <stddef.h> /* for size_t */
+# define R_SIZE_T size_t
 #endif
 
 #ifdef  __cplusplus
@@ -44,8 +47,8 @@ void	vmaxset(const void *);
 void	R_gc(void);
 int	R_gc_running();
 
-char*	R_alloc(size_t, int);
-long double *R_allocLD(size_t nelem);
+char*	R_alloc(R_SIZE_T, int);
+long double *R_allocLD(R_SIZE_T nelem);
 char*	S_alloc(long, int);
 char*	S_realloc(char *, long, long, int);
 
